@@ -424,7 +424,7 @@ class MyLogger(logging.Logger):
         specialized LogRecords.
         """
         record = logging.getLogRecordFactory()(name, level, fn, lno, msg, args, exc_info, func, sinfo)
-        record.short_message = msg
+        record.short_message = record.getMessage()
         record.extra = extra
 
         record.datetime = self.get_color_text(self.get_datetime(), color=self.datetime_color)
